##
##  ircii.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         ircii
Summary:      Internet Relay Chat (IRC) Client
URL:          http://www.eterna.com.au/ircii/
Vendor:       Michael Sandrof, Matthew Green
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        InstantMessaging
License:      BSD
Version:      20240111
Release:      20240113

#   list of sources
Source0:      http://ircii.warped.com/ircii-%{version}.tar.bz2
Source1:      openpkg.rc
Source2:      rse.rc
Patch0:       ircii.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc
PreReq:       OpenPKG, openpkg >= 20160101, perl
BuildPreReq:  openssl
PreReq:       openssl

%description
    ircII is the classical Unix IRC client.

%track
    prog ircii = {
        version   = %{version}
        url       = http://ircii.warped.com/
        regex     = ircii-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure program
    %{l_shtool} subst \
        -e 's;-lcrypto -lssl;-lssl -lcrypto;g' \
        configure
    libs="-liconv"
    case "%{l_platform -t}" in
        *-sunos* ) libs="-lsocket -lnsl" ;;
    esac
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    LIBS="$libs" \
    IRCLIB="\${datarootdir}/ircii" \
    ./configure \
        --prefix=%{l_prefix} \
        --libexecdir=%{l_prefix}/libexec/ircii \
        --mandir=%{l_prefix}/man \
        --with-openssl=%{l_prefix} \
        --disable-ipv6

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   install program
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT

    #   post-adjust installation installation
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    mv $RPM_BUILD_ROOT%{l_prefix}/bin/irc-[0-9]* \
       $RPM_BUILD_ROOT%{l_prefix}/bin/irc
    mv $RPM_BUILD_ROOT%{l_prefix}/man/man1/ircII.1 \
       $RPM_BUILD_ROOT%{l_prefix}/man/man1/irc.1
    rm -f $RPM_BUILD_ROOT%{l_prefix}/bin/ircbug
    rm -f $RPM_BUILD_ROOT%{l_prefix}/man/man1/ircbug.1
    rm -f "$RPM_BUILD_ROOT%{l_prefix}/share/ircii/help/!"
    rm -f "$RPM_BUILD_ROOT%{l_prefix}/share/irci/help/:"

    #   install additional run-command scripts
    %{l_shtool} install -c -m 644 \
        %{SOURCE openpkg.rc} $RPM_BUILD_ROOT%{l_prefix}/share/ircii/script/openpkg
    %{l_shtool} install -c -m 644 \
        %{SOURCE rse.rc} $RPM_BUILD_ROOT%{l_prefix}/share/ircii/script/rse

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

